[![Codacy Badge](https://app.codacy.com/project/badge/Grade/6796cdd900fe464e99fd53f80be75f9a)](https://www.codacy.com/gh/kokarare1212/Radiko.py/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=kokarare1212/Radiko.py&amp;utm_campaign=Badge_Grade)
[![DeepSource](https://deepsource.io/gh/kokarare1212/Radiko.py.svg/?label=active+issues&show_trend=true)](https://deepsource.io/gh/kokarare1212/Radiko.py/?ref=repository-badge)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)  
# radiko.py
Python製の非公式radikoライブラリ
